<?php

/**
 * @file build_test_class.inc
 *
 * Bootstrapped by phpunit using phpunit.xml, to be
 * available for all tests
 */

/**
 * @class BuildTest
 *
 * Abstract class with no tests of its own
 */
abstract class BuildTest extends PHPUnit_Framework_TestCase {

  // All the alias details, as a class variable (see below)
  static $alias_details;
  // Location of drush_instance files
  static $drush_instance_root;

  /**
   * We only want to assemble alias details the once, so use phpunit's
   * setUpBeforeClass class method and store in a static variable
   */
  public static function setUpBeforeClass() {
    // Run parent's own method
    parent::setUpBeforeClass();

    // Where's Drush? Unlike Drush's own test cases, we have to find it!
    require_once(dirname(exec("readlink -f `which drush`")) . '/includes/bootstrap.inc');
    drush_bootstrap_prepare();

    // Need to set umask for all child processes, so that we can detect
    // that permissions-wrangling has really worked
    umask(022);

    // Now start setting up our custom alias(es): need utility functions
    // for this (ideally we'd use drush_boostrap())
    self::$drush_instance_root = dirname(__FILE__) . "/..";
    require_once(self::$drush_instance_root . "/instance.drush.inc");

    // Include our test aliases
    drush_set_context('ALIAS_PATH', array(dirname(__FILE__)));
    // Instantiate @instance.local...
    drush_sitealias_get_record('@instance.local');
    // ... then store it on the class
    $aliases =& drush_get_context('site-aliases');
    self::$alias_details['alias'] =& $aliases['@instance.local'];

    // Site root needs to be a unique temporary directory
    self::$alias_details['alias']['root'] = $site_root = _drush_instance_tmp_unique();

    // Finally, write this data out, so that the separate processes can see it
    // Add a random numeric suffix to alias name, to avoid clash with existing aliases
    drush_mkdir(self::$alias_details['alias_dir'] = _drush_instance_tmp_unique());
    self::$alias_details['alias_name'] = $name = "instance" . uniqid() . ".local";
    // Propagate this unique name into the rsync folder definition
    if (isset(self::$alias_details['alias']['instance']['paths']['sites/includes_rsynced'])) {
      self::$alias_details['alias']['instance']['paths']['sites/includes_rsynced']['source']['from']
        = preg_replace('/instance[0-9a-z]*.local/', self::$alias_details['alias_name'],
          self::$alias_details['alias']['instance']['paths']['sites/includes_rsynced']['source']['from']);
    }

    // Now write aliases
    file_put_contents(self::$alias_details['alias_dir'] . "/aliases.drushrc.php",
      "<?php \$aliases['$name'] = "
      . var_export(self::$alias_details['alias'], TRUE) . ";");
  }

  /**
   * Implements tearDownAfterClass()
   */
  public static function tearDownAfterClass() {
    parent::tearDownAfterClass();
    drush_bootstrap_finish();
  }

  /**
   * Implements $this->setup()
   * Moves class variables onto the object, for convenience
   */
  function setUp() {
    parent::setUp();
    foreach(self::$alias_details as $k => $v) {
      $this->{$k} = $v;
    }

    // Some other special variables
    $this->site_root = $this->alias['root'];
    $this->sites_default = $this->site_root . "/sites/default";
  }

  /**
   * Function to build an instance based on alias name and directory
   * Defaults to obtaining these two arguments from the current object
   * Optional third parameter can provide extra arguments
   */
  protected function _instance_build($alias_name = NULL, $alias_dir = NULL, $other_arguments = '') {
    $alias_name = $alias_name ? $alias_name : $this->alias_name;
    $alias_dir = $alias_dir ? $alias_dir : $this->alias_dir;

    $success = drush_shell_exec("/usr/bin/drush instance-build @$alias_name "
      . " --alias-path=$alias_dir --templates=all --include="
      . self::$drush_instance_root
      . " $other_arguments");

    return array(
      'success' => $success,
      'output' => drush_shell_exec_output(),
    );
  }
}

/**
 * @class BuildTestWithBuild
 *
 * Extend BuildTest to actually perform a build as part of class setup
 */
abstract class BuildTestWithBuild extends BuildTest {
  /**
   * Implements setUpBeforeClass()
   *
   * We want an existing build as a pre-requisite
   */
  public static function setUpBeforeClass($other_arguments = '') {
    parent::setUpBeforeClass();

    return self::_instance_build(
      self::$alias_details['alias_name'],
      self::$alias_details['alias_dir'],
      $other_arguments
    );
  }
}
